@@ -1,12 +1,16 @@
 from __future__ import absolute_import, division, print_function
 
+from distutils.version import LooseVersion
+
 import pytest
 import numpy as np
 from mock import MagicMock
 
+from qtpy import QT_VERSION
 from qtpy import QtCore, QtGui
-from glue.utils.qt import get_qapp
 from qtpy.QtCore import Qt
+
+from glue.utils.qt import get_qapp
 from glue.core import Data, DataCollection
 from glue.utils.qt import qt_to_mpl_color
 from glue.app.qt import GlueApplication
@@ -15,6 +19,8 @@ from ..data_viewer import DataTableModel, TableViewer
 
 from glue.core.edit_subset_mode import AndNotMode, OrMode, ReplaceMode
 
+QT_LT_58 = LooseVersion(QT_VERSION) < LooseVersion('5.8')
+
 
 class TestDataTableModel():
 
@@ -26,11 +32,11 @@ class TestDataTableModel():
         assert self.model.columnCount() == 2
 
     def test_column_count_hidden(self):
-        self.model.show_hidden = True
+        self.model.show_coords = True
         assert self.model.columnCount() == 4
 
     def test_header_data(self):
-        for i, c in enumerate(self.data.visible_components):
+        for i, c in enumerate(self.data.main_components):
             result = self.model.headerData(i, Qt.Horizontal, Qt.DisplayRole)
             assert result == c.label
 
@@ -42,7 +48,7 @@ class TestDataTableModel():
         assert self.model.rowCount() == 4
 
     def test_data(self):
-        for i, c in enumerate(self.data.visible_components):
+        for i, c in enumerate(self.data.main_components):
             for j in range(self.data.size):
                 idx = self.model.index(j, i)
                 result = self.model.data(idx, Qt.DisplayRole)
@@ -52,7 +58,7 @@ class TestDataTableModel():
     def test_data_2d(self):
         self.data = Data(x=[[1, 2], [3, 4]], y=[[2, 3], [4, 5]])
         self.model = DataTableModel(self.data)
-        for i, c in enumerate(self.data.visible_components):
+        for i, c in enumerate(self.data.main_components):
             for j in range(self.data.size):
                 idx = self.model.index(j, i)
                 result = self.model.data(idx, Qt.DisplayRole)
@@ -285,10 +291,11 @@ def test_table_widget_session_no_subset(tmpdir):
     gapp2.viewers[0][0]
 
 
+@pytest.mark.skipif('QT_LT_58')
 def test_change_components():
 
     # Regression test for a bug that caused table viewers to not update when
-    # adding/removing components.
+    # adding/removing components. For now, this does not work with Qt 5.7.
 
     app = get_qapp()  # noqa
 
